@@ -1,4 +1,4 @@
-from .pagination import EmbedPaginator, BotEmbedPaginator
+from .pagination import EmbedPaginator, BotEmbedPaginator, ControlEmojis
 from .confirmation import Confirmation, BotConfirmation
 from .multiple_choice import MultipleChoice, BotMultipleChoice
 from . import abc
